# JFrog Security Holding Package

This is a security holding package, a placeholder for a deleted package susceptible to hijacking.

This package does not contain malicious code.

For inquiries: [sec_reporting@service.jfrog.com](sec_reporting@service.jfrog.com)

